from setuptools import find_packages, setup

setup(
    name='Artools',
    packages=find_packages(),
    version='0.0.1',
    description='My first Python library',
    author='Arthur Prigent',
    author_email='artprigent@gmail.com',
    license='MIT',
    install_requires=['']
)